/**
    @file adt7310.h

    @brief Library file for ADT7310
 *

    @version 1.0.0

**/
/*
 * ============================================================================
 * History
 * =======
 *
 * (C) Copyright 2014, Future Technology Devices International Ltd.
 * ============================================================================
 *
 * This source code ("the Software") is provided by Future Technology Devices
 * International Limited ("FTDI") subject to the licence terms set out
 * http://www.ftdichip.com/FTSourceCodeLicenceTerms.htm ("the Licence Terms").
 * You must read the Licence Terms before downloading or using the Software.
 * By installing or using the Software you agree to the Licence Terms. If you
 * do not agree to the Licence Terms then do not download or use the Software.
 *
 * Without prejudice to the Licence Terms, here is a summary of some of the key
 * terms of the Licence Terms (and in the event of any conflict between this
 * summary and the Licence Terms then the text of the Licence Terms will
 * prevail).
 *
 * The Software is provided "as is".
 * There are no warranties (or similar) in relation to the quality of the
 * Software. You use it at your own risk.
 * The Software should not be used in, or for, any medical device, system or
 * appliance. There are exclusions of FTDI liability for certain types of loss
 * such as: special loss or damage; incidental loss or damage; indirect or
 * consequential loss or damage; loss of income; loss of business; loss of
 * profits; loss of revenue; loss of contracts; business interruption; loss of
 * the use of money or anticipated savings; loss of information; loss of
 * opportunity; loss of goodwill or reputation; and/or loss of, damage to or
 * corruption of data.
 * There is a monetary cap on FTDI's liability.
 * The Software may have subsequently been amended by another user and then
 * distributed by that other user ("Adapted Software").  If so that user may
 * have additional licence terms that apply to those amendments. However, FTDI
 * has no liability in relation to those amendments.
 * ============================================================================
 */

#ifndef ADT7310_H_
#define ADT7310_H_

#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */

/* INCLUDES ************************************************************************/
#include <stdlib.h>
#include <stdint.h>
#include <string.h>
#include <stdio.h>

#include "ft51_spim.h"

/* CONSTANTS ***********************************************************************/

/* TYPES ***************************************************************************/
/**
 @name ADT7310 temperature sensor register addresses
 @brief Register addresses used to access setpoints, readings and status
        in the ADT7310 device.
 */
enum {
	ADT7310_REG_STATUS = 0x0,
	ADT7310_REG_CONFIGURATION = 0x1,
	ADT7310_REG_TEMPERATURE = 0x2,
	ADT7310_REG_ID = 0x3,
	ADT7310_REG_TCRIT = 0x4,
	ADT7310_REG_THYST = 0x5,
	ADT7310_REG_THIGH = 0x6,
	ADT7310_REG_TLOW = 0x7,
};

/**
 @brief Structure for command byte of the ADT7310 device.
 */
struct adt7310_cmd_byte {
	uint8_t mbz:2; // Must be zero.
	uint8_t cont:1; // Activates a continuous read mode on the temperature value register only.
	uint8_t addr:3; // Target register address.
	uint8_t rw:1; // Read/write bit, where 1 indicates a read and 0 indicates a write.
	uint8_t start:1; // Set to 0 to begin a bus transaction.
};

/* GLOBAL VARIABLES ****************************************************************/

/* MACROS **************************************************************************/

/* FUNCTION PROTOTYPES *************************************************************/
void temperature_setup(void);
void temperature_reset(void);
int16_t temperature_read(void);
//uint16_t temperature_config(void);


#ifdef __cplusplus
} /* extern "C" */
#endif /* __cplusplus */

#endif /* ADT7310_H_ */