/**
    @file ft51_iomux_set_pad_config.c

    @brief IOMUX Library API set pad config function.

    @version 1.0.0

**/
/*
 * ============================================================================
 * History
 * =======
 *
 * (C) Copyright 2014, Future Technology Devices International Ltd.
 * ============================================================================
 *
 * This source code ("the Software") is provided by Future Technology Devices
 * International Limited ("FTDI") subject to the licence terms set out
 * http://www.ftdichip.com/FTSourceCodeLicenceTerms.htm ("the Licence Terms").
 * You must read the Licence Terms before downloading or using the Software.
 * By installing or using the Software you agree to the Licence Terms. If you
 * do not agree to the Licence Terms then do not download or use the Software.
 *
 * Without prejudice to the Licence Terms, here is a summary of some of the key
 * terms of the Licence Terms (and in the event of any conflict between this
 * summary and the Licence Terms then the text of the Licence Terms will
 * prevail).
 *
 * The Software is provided "as is".
 * There are no warranties (or similar) in relation to the quality of the
 * Software. You use it at your own risk.
 * The Software should not be used in, or for, any medical device, system or
 * appliance. There are exclusions of FTDI liability for certain types of loss
 * such as: special loss or damage; incidental loss or damage; indirect or
 * consequential loss or damage; loss of income; loss of business; loss of
 * profits; loss of revenue; loss of contracts; business interruption; loss of
 * the use of money or anticipated savings; loss of information; loss of
 * opportunity; loss of goodwill or reputation; and/or loss of, damage to or
 * corruption of data.
 * There is a monetary cap on FTDI's liability.
 * The Software may have subsequently been amended by another user and then
 * distributed by that other user ("Adapted Software").  If so that user may
 * have additional licence terms that apply to those amendments. However, FTDI
 * has no liability in relation to those amendments.
 * ============================================================================
 */
#include "ft51_iomux.h"


void IOMUX_set_pad_config(const IOMUX_PAD pad,
                                IOMUX_PAD_DRIVE_CURRENT drive,
                                IOMUX_PAD_TRIGGER trigger,
                                IOMUX_PAD_SLEW_RATE slew,
                                IOMUX_PAD_PULL pull)
{
    uint8_t temp = 0x00;

    /** IOMUX_PAD   | Register
            0       |   0x0A    DIGITAL_CONTROL_AIO_0
            1       |   0x0B    DIGITAL_CONTROL_AIO_1
            ...
            16      |   0x1A    DIGITAL_CONTROL_GPIO_0
            17      |   0x1B    DIGITAL_CONTROL_GPIO_1
        etc.

        Hence, offset = 0x0A
    **/

    temp    = drive
            | trigger<<4
            | slew<<5
            | pull<<2;

    IO_REG_GENERAL_WRITE(pad+0x0A, temp);
}